require 'fileutils'
require 'backdrop'
require 'backdrop/app'

module Backdrop
  class APIBuilder
    def initialize(default_url = nil)
      @config = Backdrop.configuration
      @url = default_url
    end

    def build(input)
      hashes = Array(input).map(&:to_h)
      url = extract_url(hashes)

      if input.respond_to?(:map)
        write_api(@url || url, hashes)
      else
        write_api(@url || url, hashes.first)
      end
    end

    private

    def extract_url(hashes)
      hashes.reduce(nil) do |_, record|
        record.delete :backdrop_url
      end
    end

    def write_api(url, hashes)
      base_dir = @config.output_dir
      file = "#{File.join(base_dir, url)}.json"
      FileUtils.mkdir_p(File.dirname(file))
      File.write(file, JSON.generate(hashes))
    end
  end
end
